import React from 'react';
import Point from './Point';
import SvgArrow from './SvgArrow';
import { AnchorPositionType, EntityRelationType, LineType, ShapeType, SourceToTargetType, ValidLineStyles } from './types';
export declare type ArcherContainerContextType = {
    registerChild: (arg0: string, arg1: HTMLElement) => void;
    registerTransitions: (arg0: string, arg1: SourceToTargetType[]) => void;
    unregisterChild: (arg0: string) => void;
    unregisterTransitions: (arg0: string) => void;
} | null;
declare type FunctionChild = (context: React.Context<ArcherContainerContextType>) => React.ReactNode;
declare type Props = {
    /**
     * A color string
     *
     * @example '#ff0000'
     */
    strokeColor?: string;
    /**
     * A size in px
     */
    strokeWidth?: number;
    /**
     * A string representing an array of sizes
     * See https://www.w3schools.com/graphics/svg_stroking.asp
     */
    strokeDasharray?: string;
    style?: React.CSSProperties;
    /**
     * Style of the SVG container element. Useful if you want to add a z-index to your SVG container to draw the arrows under your elements, for example.
     */
    svgContainerStyle?: React.CSSProperties;
    className?: string;
    /**
     * Optional number for space between element and start/end of stroke
     */
    offset?: number;
    /**
     * Customize the end shape of the line. Defaults to a traditional "arrow" (triangle) shape.
     */
    endShape?: ShapeType;
    /**
     * Set this to true of you want to render a marker at the start of the line
     */
    startMarker?: boolean;
    /**
     * Set this to false of you do not want to render a marker at the end of the line
     */
    endMarker?: boolean;
    /**
     * Define how the line is drawn, grid for angles, straight for direct line and curve for curves
     */
    lineStyle?: ValidLineStyles;
    /**
     * Set this to true if you want angles instead of curves
     */
    noCurves?: boolean;
    children?: React.ReactNode | FunctionChild;
};
declare type SourceToTargetsArrayType = SourceToTargetType[];
declare type State = {
    refs: Record<string, HTMLElement>;
    sourceToTargetsMap: Record<string, SourceToTargetsArrayType>;
    observer: ResizeObserver;
    parent: HTMLElement | null | undefined;
};
export declare const ArcherContainerContextProvider: React.Provider<ArcherContainerContextType>;
export declare const ArcherContainerContextConsumer: React.Consumer<ArcherContainerContextType>;
export declare class ArcherContainer extends React.Component<Props, State> {
    arrowMarkerUniquePrefix: string;
    constructor(props: Props);
    static defaultProps: {
        endShape: {
            arrow: {
                arrowLength: number;
                arrowThickness: number;
            };
            circle: {
                radius: number;
                fillColor: string;
                strokeColor: string;
                strokeWidth: number;
            };
        };
        strokeColor: string;
        strokeWidth: number;
        svgContainerStyle: {};
    };
    componentDidMount(): void;
    componentWillUnmount(): void;
    /**
     * Use this to recompute all the arrow positions. Useful if arrows do not properly rerender
     * after the viewport or some elements moved.
     */
    refreshScreen: () => void;
    _storeParent: (ref: HTMLElement | null | undefined) => void;
    _getRectFromRef: (ref: HTMLElement | null | undefined) => DOMRect | null | undefined;
    _getParentCoordinates: () => Point;
    _getPointCoordinatesFromAnchorPosition: (position: AnchorPositionType, index: string, parentCoordinates: Point) => Point;
    _registerTransitions: (elementId: string, newSourceToTargets: SourceToTargetType[]) => void;
    _unregisterTransitions: (elementId: string) => void;
    _registerChild: (id: string, ref: HTMLElement) => void;
    _unregisterChild: (id: string) => void;
    _getSourceToTargets: () => SourceToTargetType[];
    _createShapeObj: (style: LineType) => {
        arrow: {
            arrowLength?: number | undefined;
            arrowThickness?: number | undefined;
        };
    } | {
        circle: {
            radius?: number | undefined;
            fillColor?: string | undefined;
            strokeColor?: string | undefined;
            strokeWidth?: number | undefined;
        };
    };
    _computeArrows: () => React.ReactElement<React.ComponentProps<typeof SvgArrow>, typeof SvgArrow>[];
    _buildShape: (style: LineType) => {
        markerHeight: number;
        markerWidth: number;
        path: React.ReactNode;
        refX: number;
        refY: number;
    };
    /** Generates an id for an arrow marker
     * Useful to have one marker per arrow so that each arrow
     * can have a different color!
     * */
    _getMarkerId: (source: EntityRelationType, target: EntityRelationType) => string;
    /** Generates all the markers
     * We want one marker per arrow so that each arrow can have
     * a different color or size
     * */
    _generateAllArrowMarkers: () => React.ReactElement<React.ComponentProps<'marker'>, 'marker'>[];
    _svgContainerStyle: () => Record<string, any>;
    render(): JSX.Element;
}
export default ArcherContainer;
